#' 84060 Topography, Physiographic Setting (Codes)
#'
#' A table containing the USGS Topography, Physiographic Setting (Codes)
#' parameter codes.
#'
#' @format A data frame with 18 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_84060"
#> [1] "pmcode_84060"
